@@ -8,6 +8,7 @@ import psutil
 from BaseColor.base_colors import hgreen, hblue, red, hred
 from redis import AuthenticationError
 
+from NetRecorder.common_scheduler import ComThread
 from NetRecorder.gear_for_nr import tell_the_datetime, convert_bytes, start_up_check, \
     _get_host_name, get_redis_cli, default_redis_params, get_redis_list_last, _get_current_ip4
 
@@ -108,7 +109,20 @@ def start(ip_keys, print_out=True, unit="auto", refresh_rate="s", push_redis=Fal
                                                      "location": location_info.get('location') or f"{ip_info.get('city')} - {ip_info.get('country')}",
                                                      } for i_key in s_key_set})
                     for trp in target_redis_params:
-                        get_redis_cli(trp).rpush(trp.get('insert_key', "NetRecs"), insert_obj)
+                        params = {
+                            "trp": trp,
+                            "insert_obj": insert_obj
+                        }
+                        thread = ComThread(
+                            function=push_to_server,
+                            params=params
+                        )
+                        try:
+                            thread.setDaemon(True)
+                            thread.start()
+                        except Exception as E:
+                            print(f"{red('Error in push data to server redis')}: \n{E}")
+                            return
                 s_out = "; ".join(
                     [f"{hred(ky)}: [ in: {hgreen(ne_in.get(ky))}, out: {hblue(ne_out.get(ky))} ]" for ky in s_key_set])
                 s_out = f"{'-'*42}{tell_the_datetime()} {s_out}"
@@ -136,6 +150,12 @@ def start(ip_keys, print_out=True, unit="auto", refresh_rate="s", push_redis=Fal
         return {ky: [ne_in.get(ky), ne_out.get(ky), unit, tell_the_datetime()] for ky in s_key_set}
 
 
+def push_to_server(params_data):
+    trp = params_data.get("trp")
+    insert_obj = params_data.get("insert_obj")
+    get_redis_cli(trp).rpush(trp.get('insert_key', "NetRecs"), insert_obj)
+
+
 def record_starter():
     dp = '    这是一个查看或者返回服务器流量信息的工具。\n' \
          '    https://github.com/ga1008/net_tracfic_recorder'
@@ -150,6 +170,8 @@ def record_starter():
     parser.add_argument("-pr", "--push_redis", type=str, dest="push_redis", default='n', nargs='?',
                         help=f'{da}y/n。将结果推入指定的redis，默认n。如果设置了此参数，则接下来需要提供目标redis的信息\n')
     parser.add_argument("-ps", "--place_script", dest="place_script", action="store_true",
+                        help=f'{da}y/n 做初始化检查，检查服务器脚本并复制\n')
+    parser.add_argument("-pso", "--place_script_only", dest="place_script_only", action="store_true",
                         help=f'{da}y/n 只做初始化检查，检查服务器脚本并复制\n')
     parser.add_argument("-kp", "--key_params", type=str, dest="key_params", default='input',
                         help=f'{da}关键参数提供方式，input/local/now，\n'
@@ -159,7 +181,7 @@ def record_starter():
                              'now方式仅限测试\n'
                              f'默认input\n')
     args = parser.parse_args()
-    if args.place_script:
+    if args.place_script_only:
         return start_up_check(dont_ask=True)
     n_devices = [x.strip() for x in args.net_devices.split(",")]
     unit = args.unit
@@ -169,7 +191,7 @@ def record_starter():
     push_to_redis = True if push_to_redis == 'y' or push_to_redis is None else False
     key_params = {}
     if push_to_redis:
-        start_up_check()
+        start_up_check(args.place_script)
         if key_params_mode.startswith("now"):
             key_params = key_params_mode.split(">>>>")[-1]
             try:
