@@ -99,8 +99,8 @@ def gen_server_script(local_path):
         wf.write(n_rsf)
 
 
-def start_up_check(dont_ask=False):
-    if os.path.exists("/etc/init.d/nettrarec"):
+def start_up_check(dont_ask=True):
+    if os.path.exists("/etc/rc.d/init.d/nettrarec"):
         return
     local_path = os.path.split(os.path.abspath(__file__))[0]
     gen_server_script(local_path)
@@ -115,7 +115,7 @@ def start_up_check(dont_ask=False):
     if do == 'y':
         print("adding nettrarec to system service")
         os.popen(
-            'chkconfig --add /etc/rc.d/init.d/nettrarec && chkconfig /etc/rc.d/init.d/nettrarec on && systemctl start /etc/rc.d/init.d/nettrarec'
+            'chkconfig --add /etc/rc.d/init.d/nettrarec && chkconfig nettrarec on && systemctl start nettrarec'
         ).read()
         print(green("\nnettrarec has add to system service and set to start automatically at system boot\n"))
 
